/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2008 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Include file to include all weapons in one shot ;-)
 *****************************************************************************/

#ifndef ALL_WEAPONS_H
#define ALL_WEAPONS_H

#include "weapon/airhammer.h"
#include "weapon/air_attack.h"
#include "weapon/anvil.h"
#include "weapon/auto_bazooka.h"
#include "weapon/baseball.h"
#include "weapon/bazooka.h"
#include "weapon/blowtorch.h"
#include "weapon/bounce_ball.h"
#include "weapon/cluster_bomb.h"
#include "weapon/construct.h"
#include "weapon/disco_grenade.h"
#include "weapon/dynamite.h"
#include "weapon/flamethrower.h"
#include "weapon/gnu.h"
#include "weapon/grapple.h"
#include "weapon/grenade.h"
#include "weapon/gun.h"
#include "weapon/jetpack.h"
#include "weapon/lowgrav.h"
#include "weapon/mine.h"
#include "weapon/parachute.h"
#include "weapon/polecat.h"
#include "weapon/riot_bomb.h"
#include "weapon/shotgun.h"
#include "weapon/skip_turn.h"
#include "weapon/snipe_rifle.h"
#include "weapon/submachine_gun.h"
#include "weapon/suicide.h"
#include "weapon/supertux.h"
#include "weapon/syringe.h"
#include "weapon/teleportation.h"
#include "weapon/cluzooka.h"
#include "weapon/footbomb.h"

#endif
